@@ -248,8 +248,7 @@ update_function (gpointer data)
                         g_source_remove(alrm->repeat_timeout);
                     alrm->repeat_timeout = g_timeout_add(pd->repeat_interval * 1000, repeat_alarm, alrm);
                 } else {
-                    if (command)
-                        g_free(command);
+                    g_free(command);
                     command = NULL;
                 }
             }
@@ -332,7 +331,11 @@ start_timer (plugin_data *pd, alarm_t* alrm)
   if (!alrm->is_countdown)
     {
 
-      current = g_date_time_new_now_local ();
+      if (alrm->is_utc)
+        current = g_date_time_new_now_utc ();
+      else
+        current = g_date_time_new_now_local ();
+
       cur_h = g_date_time_get_hour   (current);
       cur_m = g_date_time_get_minute (current);
       cur_s = g_date_time_get_second (current);
@@ -688,15 +691,23 @@ ok_edit (GtkButton *button, gpointer data)
             timeinfo = g_strdup_printf (_("%dm %ds"), t2, t3);
           else
             timeinfo = g_strdup_printf (_("%ds"), t3);
+
         }
       else
         {
+
+          alrm->is_utc = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (adata->utc_cb));
           t1 = gtk_spin_button_get_value_as_int (
               GTK_SPIN_BUTTON (adata->time_h));
           t2 = gtk_spin_button_get_value_as_int (
               GTK_SPIN_BUTTON (adata->time_m));
           t = t1 * 60 + t2;
-          timeinfo = g_strdup_printf (_("At %02d:%02d"), t1, t2);
+
+          if (alrm->is_utc)
+            timeinfo = g_strdup_printf (_("At %02d:%02dZ"), t1, t2);
+          else
+            timeinfo = g_strdup_printf (_("At %02d:%02d"), t1, t2);
+
         }
 
       alrm->time = t;
@@ -876,6 +887,11 @@ add_edit_clicked (GtkButton *buttonn, gpointer data)
   gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (time_m), FALSE, FALSE, 0);
   adata->time_m = time_m;
 
+  button = gtk_check_button_new_with_label (_("UTC"));
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), FALSE);
+  gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
+  adata->utc_cb = button;
+
   gtk_box_pack_start (GTK_BOX (vbox), gtk_separator_new (GTK_ORIENTATION_HORIZONTAL), FALSE, FALSE, 6);
 
   /****************/
@@ -983,6 +999,7 @@ add_edit_clicked (GtkButton *buttonn, gpointer data)
           gtk_spin_button_set_value (GTK_SPIN_BUTTON (time_h), time / 60);
           gtk_spin_button_set_value (GTK_SPIN_BUTTON (time_m), time % 60);
           gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (rb2), TRUE); // active by default
+          gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (adata->utc_cb), alrm->is_utc);
         }
     }
 
@@ -1195,7 +1212,7 @@ load_settings (plugin_data *pd)
   gchar groupname[8];
   const gchar *timerstring;
   gint groupnum, time;
-  gboolean is_cd, autostart;
+  gboolean is_cd, is_utc, autostart;
   alarm_t *alrm;
   GList *alarm_iter;
   XfceRc *rc;
@@ -1231,6 +1248,9 @@ load_settings (plugin_data *pd)
               is_cd = xfce_rc_read_bool_entry (rc, "is_countdown", TRUE);
               alrm->is_countdown = is_cd;
 
+              is_utc = xfce_rc_read_bool_entry (rc, "is_utc", FALSE);
+              alrm->is_utc = is_utc;
+
               alrm->next_alarm_groupnum = xfce_rc_read_int_entry (rc, "timernext", -1);
               /* If 'timernext' not specified, fallback to checking previously
                * used boolean setting 'is_recur' telling if alarm is self-recurring
@@ -1363,6 +1383,8 @@ save_settings (XfcePanelPlugin *plugin, plugin_data *pd)
 
       xfce_rc_write_bool_entry (rc, "is_countdown", alrm->is_countdown);
 
+      xfce_rc_write_bool_entry (rc, "is_utc", alrm->is_utc);
+
       if (alrm->next_alarm)
         xfce_rc_write_int_entry (rc, "timernext", alrm->next_alarm->next_alarm_groupnum);
 
@@ -1531,7 +1553,30 @@ spin2_changed (GtkSpinButton *button, gpointer data)
   pd->repeat_interval = gtk_spin_button_get_value_as_int (button);
 }
 
-
+/* call: xfce4-panel --plugin-event=xfce4-timer-plugin:trigger:string:<alarm-name> */
+static gboolean remote_trigger (XfcePanelPlugin *plugin,
+                                    const gchar *name,
+                                    const GValue *value,
+                                    plugin_data *pd)
+{
+  g_return_val_if_fail (value != NULL, FALSE);
+  if (strcmp (name, "trigger") == 0) {
+    if (value != NULL && G_VALUE_HOLDS_STRING (value)) {
+      const GList * list = NULL;
+      const gchar *alarm_to_trigger = g_value_get_string (value);
+      list = pd->alarm_list;
+      while (list) {
+        alarm_t *alarm = list->data;
+        if (strcmp (alarm->name, alarm_to_trigger) == 0) {
+          start_timer(pd, alarm);
+          return TRUE;
+        }
+        list = g_list_next (list);
+      }
+    }
+  }
+  return TRUE;
+}/* remote_trigger() */
 
 /* Options dialog */
 static void
@@ -1548,10 +1593,10 @@ plugin_create_options (XfcePanelPlugin *plugin, plugin_data *pd)
 
   xfce_panel_plugin_block_menu (plugin);
 
-  header = xfce_titled_dialog_new_with_buttons (
+  header = xfce_titled_dialog_new_with_mixed_buttons (
       _("Timer Options"),
       GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (plugin))),
-      GTK_DIALOG_DESTROY_WITH_PARENT, _("Close"), GTK_RESPONSE_OK, NULL);
+      GTK_DIALOG_DESTROY_WITH_PARENT, "", _("Close"), GTK_RESPONSE_OK, NULL);
 
   dlg = header;
 
@@ -1741,10 +1786,7 @@ static void
 show_about_window (XfcePanelPlugin *plugin, plugin_data *pd)
 {
   const gchar *author[] =
-    { "Kemal Ilgar Eroğlu <ilgar_eroglu@yahoo.com>, 2005-2018",
-      "The Xfce development team, 2019-2023",
-      NULL
-    };
+    { "Kemal Ilgar Eroğlu <ilgar_eroglu@yahoo.com>", NULL };
   const gchar *translators =
       "Mohammad Alhargan <malham1@hotmail.com> \n\
 Marcos Antonio Alvarez Costales <marcoscostales@gmail.com> \n\
@@ -1788,7 +1830,7 @@ Cheng-Chia Tseng <pswo10680@gmail.com>\n";
       _("A plugin to define countdown timers or alarms at given times."),
       "website",
       "https://docs.xfce.org/panel-plugins/xfce4-timer-plugin",
-      "copyright", _("Copyright (c) 2005-2023\n"), "authors", author,
+      "copyright", "Copyright \302\251 2005-2024 The Xfce development team", "authors", author,
       "translator-credits", translators, NULL);
 }
 
@@ -1876,6 +1918,8 @@ create_plugin_control (XfcePanelPlugin *plugin)
   g_signal_connect (plugin, "configure-plugin",
                     G_CALLBACK (plugin_create_options), pd);
 
+  g_signal_connect (plugin, "remote-event", G_CALLBACK (remote_trigger), pd);
+
   xfce_panel_plugin_menu_show_about (plugin);
   g_signal_connect (plugin, "about", G_CALLBACK (show_about_window), pd);
 }
